@@ -183,7 +183,7 @@ namespace ImLogViewer {
 				
 				if (speaking_to == null)
 					SetWindowTitle (log.SpeakingTo);
-					timeline.Add (log, log.StartTime);
+				timeline.Add (log, log.StartTime);
 			}
 
 			index_thread_notify.WakeupMain ();
@@ -288,6 +288,14 @@ namespace ImLogViewer {
 					break;
 				tree_store.Remove (ref iter);
 			}
+
+			// Remove all the categories that dont have any matches
+			tree_store.GetIterFirst (out iter);
+
+			do {
+				if (tree_store.IterNChildren (iter) < 1)
+					tree_store.Remove (ref iter);
+			} while (tree_store.IterNext (ref iter));
 			
 			ScrollToLog (selected);
 			RenderConversation (selected);
