@@ -27,6 +27,7 @@
 using System;
 using System.Collections;
 using System.IO;
+using System.Diagnostics;
 using System.Reflection;
 using System.Xml.Serialization;
 using System.Text.RegularExpressions;
@@ -46,10 +47,6 @@ namespace Beagle.Util {
 		public static DaemonConfig Daemon = null;
 		public static SearchingConfig Searching = null;
 
-//#if ENABLE_WEBSERVICES		
-		public static NetworkingConfig Networking = null;
-		public static WebServicesConfig WebServices = null;
-//#endif 		
 		private static string configs_dir;
 		private static Hashtable mtimes;
 		private static Hashtable subscriptions;
@@ -148,16 +145,6 @@ namespace Beagle.Util {
 		        Searching = (SearchingConfig) temp;
 			NotifySubscribers (Searching);
 
-//#if ENABLE_WEBSERVICES
-			LoadFile (typeof (NetworkingConfig), Networking, out temp, force);
-		    	Networking = (NetworkingConfig) temp;
-			NotifySubscribers (Networking);
-			
-			LoadFile (typeof (WebServicesConfig), WebServices, out temp, force);
-		    	WebServices = (WebServicesConfig) temp;
-			NotifySubscribers (WebServices);
-//#endif
-
 			watching_for_updates = true;
 		}
 
@@ -201,7 +188,7 @@ namespace Beagle.Util {
 				XmlSerializer serializer = new XmlSerializer (type);
 				section = (Section) serializer.Deserialize (fs);
 			} catch (Exception e) {
-				Logger.Log.Error ("Could not load configuration from {0}: {1}", filename, e.Message);
+				Logger.Log.Error (e, "Could not load configuration from {0}:", filename);
 				if (fs != null)
 					fs.Close ();
 				if (current == null)
@@ -334,60 +321,32 @@ namespace Beagle.Util {
 				}
 			}
 
-			// Best window position and dimension
+			// BeagleSearch window position and dimension
 			// stored as percentage of screen co-ordinates
 			// to deal with change of resolution problem - hints from tberman
 
-			private float best_pos_x = 0;
-			public float BestPosX {
-				get { return best_pos_x; }
-				set { best_pos_x = value; }
+			private float beagle_search_pos_x = 0;
+			public float BeaglePosX {
+				get { return beagle_search_pos_x; }
+				set { beagle_search_pos_x = value; }
 			}
 			
-			private float best_pos_y = 0;
-			public float BestPosY {
-				get { return best_pos_y; }
-				set { best_pos_y = value; }
+			private float beagle_search_pos_y = 0;
+			public float BeaglePosY {
+				get { return beagle_search_pos_y; }
+				set { beagle_search_pos_y = value; }
 			}
 			
-			// dont explicitly set height on first run
-			private float best_width = 0; 
-			public float BestWidth {
-				get { return best_width; }
-				set { best_width = value; }
+			private float beagle_search_width = 0; 
+			public float BeagleSearchWidth {
+				get { return beagle_search_width; }
+				set { beagle_search_width = value; }
 			}
 
-			private float best_height = 0; // -ditto-
-			public float BestHeight {
-				get { return best_height; }
-				set { best_height = value; }
-			}
-
-			// FIXME Change names when Holmes is released under new name
-			// Holmes window position and dimension
-
-			private float holmes_pos_x = 0;
-			public float HolmesPosX {
-				get { return holmes_pos_x; }
-				set { holmes_pos_x = value; }
-			}
-			
-			private float holmes_pos_y = 0;
-			public float HolmesPosY {
-				get { return holmes_pos_y; }
-				set { holmes_pos_y = value; }
-			}
-			
-			private float holmes_width = 0; 
-			public float HolmesWidth {
-				get { return holmes_width; }
-				set { holmes_width = value; }
-			}
-
-			private float holmes_height = 0;
-			public float HolmesHeight {
-				get { return holmes_height; }
-				set { holmes_height = value; }
+			private float beagle_search_height = 0;
+			public float BeagleSearchHeight {
+				get { return beagle_search_height; }
+				set { beagle_search_height = value; }
 			}
 
 			// ah!We want a Queue but Queue doesnt serialize *easily*
@@ -407,18 +366,21 @@ namespace Beagle.Util {
 				set { static_queryables = value; }
 			}
 
-			private ArrayList allowed_backends = new ArrayList ();
-			public ArrayList AllowedBackends {
-				get { return allowed_backends; }
-				set { allowed_backends = value; }
-			}
-
+			// By default, every backend is allowed.
+			// Only maintain a list of denied backends.
 			private ArrayList denied_backends = new ArrayList ();
 			public ArrayList DeniedBackends {
 				get { return denied_backends; }
 				set { denied_backends = value; }
 			}
 
+			private bool allow_static_backend = false; // by default, false
+			public bool AllowStaticBackend {
+				get { return allow_static_backend; }
+				// Don't really want to expose this, but serialization requires it
+				set { allow_static_backend = value; }
+			}
+
 			private bool index_synchronization = true;
 			public bool IndexSynchronization {
 				get { return index_synchronization; }
@@ -426,6 +388,28 @@ namespace Beagle.Util {
 				set { index_synchronization = value; }
 			}
 
+			[ConfigOption (Description="Enable a backend", Params=1, ParamsDescription="Name of the backend to enable")]
+			internal bool AllowBackend (out string output, string [] args)
+			{
+				denied_backends.Remove (args [0]);
+				output = "Backend allowed (need to restart beagled for changes to take effect).";
+				return true;
+			}
+
+			[ConfigOption (Description="Disable a backend", Params=1, ParamsDescription="Name of the backend to disable")]
+			internal bool DenyBackend (out string output, string [] args)
+			{
+				denied_backends.Add (args [0]);
+				output = "Backend disabled (need to restart beagled for changes to take effect).";
+				return true;
+			}
+			
+			private bool allow_root = false;
+			public bool AllowRoot {
+				get { return allow_root; }
+				set { allow_root = value; }
+			}
+
 			[ConfigOption (Description="Add a static queryable", Params=1, ParamsDescription="Index path")]
 			internal bool AddStaticQueryable (out string output, string [] args)
 			{
@@ -451,13 +435,32 @@ namespace Beagle.Util {
 				return true;
 			}
 
+			[ConfigOption (Description="Toggles whether static indexes will be enabled")]
+			internal bool ToggleAllowStaticBackend (out string output, string [] args)
+			{
+				allow_static_backend = !allow_static_backend;
+				output = "Static indexes are " + ((allow_static_backend) ? "enabled" : "disabled") + " (need to restart beagled for changes to take effect).";
+				return true;
+			}		
+
 			[ConfigOption (Description="Toggles whether your indexes will be synchronized locally if your home directory is on a network device (eg. NFS/Samba)")]
 			internal bool ToggleIndexSynchronization (out string output, string [] args)
 			{
 				index_synchronization = !index_synchronization;
 				output = "Index Synchronization is " + ((index_synchronization) ? "enabled" : "disabled") + ".";
 				return true;
-			}		
+			}
+
+			[ConfigOption (Description="Toggles whether Beagle can be run as root")]
+			internal bool ToggleAllowRoot (out string output, string [] args)
+			{
+				allow_root = ! allow_root;
+				if (allow_root)
+					output = "Beagle is now permitted to run as root";
+				else
+					output = "Beagle is no longer permitted to run as root";
+				return true;
+			}
 		}
 
 		[ConfigSection (Name="indexing")]
@@ -467,7 +470,7 @@ namespace Beagle.Util {
 			[XmlArray]
 			[XmlArrayItem(ElementName="Root", Type=typeof(string))]
 			public ArrayList Roots {
-				get { return ArrayList.ReadOnly (roots); }
+				get { return roots; }
 				set { roots = value; }
 			}
 
@@ -477,11 +480,17 @@ namespace Beagle.Util {
 				set { index_home_dir = value; }
 			}
 
+			private bool index_on_battery = true;
+			public bool IndexOnBattery {
+				get { return index_on_battery; }
+				set { index_on_battery = value; }
+			}
+
 			private ArrayList excludes = new ArrayList ();
 			[XmlArray]
 			[XmlArrayItem (ElementName="ExcludeItem", Type=typeof(ExcludeItem))]
 			public ArrayList Excludes {
-				get { return ArrayList.ReadOnly (excludes); }
+				get { return excludes; }
 				set { excludes = value; }
 			}
 
@@ -508,6 +517,17 @@ namespace Beagle.Util {
 				return true;
 			}
 
+			[ConfigOption (Description="Toggles whether any data should be indexed if the system is on battery")]
+			internal bool IndexWhileOnBattery (out string output, string [] args)
+			{
+				if (index_on_battery)
+					output = "Data will not be indexed while on battery.";
+				else
+					output = "Data will be indexed while on battery.";
+				index_on_battery = !index_on_battery;
+				return true;
+			}
+
 			[ConfigOption (Description="Add a root path to be indexed", Params=1, ParamsDescription="A path")]
 			internal bool AddRoot (out string output, string [] args)
 			{
@@ -574,127 +594,6 @@ namespace Beagle.Util {
 
 		}
 
-//#if ENABLE_WEBSERVICES
-		[ConfigSection (Name="webservices")]
-		public class WebServicesConfig: Section 
-		{
-			private ArrayList publicFolders = new ArrayList ();
-			[XmlArray]
-			[XmlArrayItem(ElementName="PublicFolders", Type=typeof(string))]
-			public ArrayList PublicFolders {
-				get { return ArrayList.ReadOnly (publicFolders); }
-				set { publicFolders = value; }
-			}
-
-			private bool allowGlobalAccess = true;
-			public bool AllowGlobalAccess {
-				get { return allowGlobalAccess; }
-				set { allowGlobalAccess = value; }
-			}
-
-			[ConfigOption (Description="List the public folders", IsMutator=false)]
-			internal bool ListPublicFolders(out string output, string [] args)
-			{
-				output = "Current list of public folders:\n";
-
-				foreach (string pf in publicFolders)
-					output += " - " + pf + "\n";
-
-				return true;
-			}
-			
-			[ConfigOption (Description="Check current configuration of global access to Beagle web-services", IsMutator=false)]
-			internal bool CheckGlobalAccess(out string output, string [] args)
-			{
-				if (allowGlobalAccess)
-					output = "Global Access to Beagle WebServices is currently ENABLED.";
-				else
-					output = "Global Access to Beagle WebServices is currently DISABLED.";
-
-				return true;
-			}
-			
-			[ConfigOption (Description="Enable/Disable global access to Beagle web-services")]
-			internal bool SwitchGlobalAccess (out string output, string [] args)
-			{
-				allowGlobalAccess = !allowGlobalAccess;			
-				
-				if (allowGlobalAccess)
-					output = "Global Access to Beagle WebServices now ENABLED.";
-				else
-					output = "Global Access to Beagle WebServices now DISABLED.";
-
-				return true;
-			}
-
-			[ConfigOption (Description="Add public web-service access to a folder", Params=1, ParamsDescription="A path")]
-			internal bool AddPublicFolder (out string output, string [] args)
-			{
-				publicFolders.Add (args [0]);					
-				output = "PublicFolder " + args[0] + " added.";
-				return true;
-			}
-
-			[ConfigOption (Description="Remove public web-service access to a folder", Params=1, ParamsDescription="A path")]
-			internal bool DelPublicFolder (out string output, string [] args)
-			{
-				publicFolders.Remove (args [0]);		
-				output = "PublicFolder " + args[0] + " removed.";
-				return true;
-			}			
-		}
-
-		[ConfigSection (Name="networking")]
-		public class NetworkingConfig: Section 
-		{
-			private ArrayList netBeagleNodes = new ArrayList ();
-			
-			[XmlArray]
-			[XmlArrayItem(ElementName="NetBeagleNodes", Type=typeof(string))]
-			public ArrayList NetBeagleNodes {
-				get { return ArrayList.ReadOnly (netBeagleNodes); }
-				set { netBeagleNodes = value; }
-			}
-
-			[ConfigOption (Description="List Networked Beagle Daemons to query", IsMutator=false)]
-			internal bool ListBeagleNodes (out string output, string [] args)
-			{
-				output = "Current list of Networked Beagle Daemons to query:\n";
-
-				foreach (string nb in netBeagleNodes)
-					output += " - " + nb + "\n";
-				
-				return true;
-			}
-
-			[ConfigOption (Description="Add a Networked Beagle Daemon to query", Params=1, ParamsDescription="HostName:PortNo")]
-			internal bool AddBeagleNode (out string output, string [] args)
-			{
-				string node = args[0];
-				
-				if (((string[])node.Split(':')).Length < 2)
-					node = args [0].Trim() + ":8888";
-							
-				netBeagleNodes.Add(node);			
-				output = "Networked Beagle Daemon \"" + node +"\" added.";
-				return true;
-			}
-
-			[ConfigOption (Description="Remove a configured Networked Beagle Daemon", Params=1, ParamsDescription="HostName:PortNo")]
-			internal bool DelBeagleNode (out string output, string [] args)
-			{
-				string node = args[0];
-				
-				if (((string[])node.Split(':')).Length < 2)
-					node = args [0].Trim() + ":8888";
-							
-				netBeagleNodes.Remove(node);					
-				output = "Networked Beagle Daemon \"" + node +"\" removed.";
-				return true;
-			}
-		}
-//#endif
-
 		public class Section {
 			[XmlIgnore]
 			public bool SaveNeeded = false;
