@@ -65,37 +65,6 @@ namespace Beagle.Util {
 			Logger.Log.Debug ("{0}", str);
 		}
 
-		public class ImBuddyComparer : IComparer {
-			
-			int IComparer.Compare (Object x, Object y) {
-				string accountx, accounty;
-	
-				try {
-					accountx = ((ImBuddy) x).BuddyAccountName;
-				} catch {
-					accountx = "";
-				}
-				
-				try {
-					accounty = ((ImBuddy) y).BuddyAccountName;
-				} catch {
-					accounty = "";
-				}
-	
-				return System.String.Compare (accountx, accounty);
-			}
-		}
-
-		public class ImBuddyAliasComparer : IComparer {
-			
-			int IComparer.Compare (Object x, Object y) {
-				try {
-					return System.String.Compare ((string)x, ((ImBuddy) y).BuddyAccountName);
-				} catch {
-					return System.String.Compare (((ImBuddy) x).BuddyAccountName, (string)y);
-				}
-			}
-		}
 	}
 	
 	public class GaimBuddyListReader : ImBuddyListReader {
@@ -173,7 +142,7 @@ namespace Beagle.Util {
 					AddBuddy (buddy);
 				}
 			} catch (Exception ex) {
-				Logger.Log.Error ("Caught exception while trying to parse Gaim contact list: {0}", ex.Message);
+				Logger.Log.Error (ex, "Caught exception while trying to parse Gaim contact list:");
 			}
 		}
 
@@ -380,7 +349,7 @@ namespace Beagle.Util {
 				foreach (XmlNode contact in accounts.SelectNodes ("//meta-contact"))
 					AddContact (contact);
 			} catch (Exception ex) {
-				Logger.Log.Error ("Caught exception while trying to parse Kopete contact list: {0}", ex.Message);
+				Logger.Log.Error (ex, "Caught exception while trying to parse Kopete contact list:");
 			}
 		}
 
