@@ -42,7 +42,7 @@ namespace Beagle.Util {
 
 		//////////////////////////
 
-		public delegate string Pull ();
+		public delegate bool Pull (StringBuilder buffer);
 
 		Pull pull;
 		StringBuilder pullBuffer = new StringBuilder ();
@@ -56,21 +56,11 @@ namespace Beagle.Util {
 		private void DoPull (int neededSize)
 		{
 			while (! done && pullBuffer.Length < neededSize) {
-
-				string str = null;
 				try { 
-					str = pull ();
-				} catch (Exception ex) {
-					// If we catch an exception, str will still be null
-					// and thus the code below will set done to true.
-					Logger.Log.Debug ("Caught exception pulling text from {0}", pull);
-					Logger.Log.Debug (ex);
+					done = ! pull (pullBuffer);
+				} catch (Exception e) {
+					Logger.Log.Debug (e, "Caught exception pulling text from {0}", pull);
 				}
-
-				if (str != null) {
-					pullBuffer.Append (str);
-				} else
-					done = true;
 			}
 		}
 
@@ -137,7 +127,7 @@ namespace Beagle.Util {
 				// in our buffer.
 				if (done) {
 					string str = pullBuffer.ToString ();
-					pullBuffer = new StringBuilder ("");
+					pullBuffer.Length = 0;
 					return str;
 				}
 
@@ -151,7 +141,7 @@ namespace Beagle.Util {
 				DoPull (2 * pullBuffer.Length);
 			
 			string str = pullBuffer.ToString ();
-			pullBuffer = new StringBuilder ("");
+			pullBuffer.Length = 0;
 			return str;
 		}
 
@@ -159,5 +149,3 @@ namespace Beagle.Util {
 
 	}
 }
-
-// last line
