@@ -28,12 +28,18 @@ using System;
 using System.Collections;
 using System.Text;
 using System.Threading;
+using System.Xml;
+using System.Xml.Serialization;
 
 namespace Beagle.Util {
 
 	public class Scheduler {
 
-		static public bool Debug = false;
+		// Fire an event if there are no tasks left to execute.
+		public delegate void EmptyQueueDelegate ();
+		public event EmptyQueueDelegate EmptyQueueEvent;
+
+		public static bool Debug = false;
 
 		public enum Priority {
 
@@ -261,12 +267,13 @@ namespace Beagle.Util {
 					try {
 						DoTaskReal ();
 					} catch (Exception ex) {
-						Logger.Log.Warn ("Caught exception in DoTaskReal");
-						Logger.Log.Warn ("        Tag: {0}", Tag);
-						Logger.Log.Warn ("    Creator: {0}", Creator);
-						Logger.Log.Warn ("Description: {0}", Description);
-						Logger.Log.Warn ("   Priority: {0} ({1})", Priority, SubPriority);
-						Logger.Log.Warn (ex);
+						Logger.Log.Warn (ex,
+								 "Caught exception in DoTaskReal\n" +
+								 "        Tag: {0}\n" +
+								 "    Creator: {0}\n" +
+								 "Description: {0}\n" +
+								 "   Priority: {0} ({1})", 
+								 Tag, Creator, Description, Priority, SubPriority);
 					}
 					sw.Stop ();
 					if (Debug)
@@ -296,8 +303,7 @@ namespace Beagle.Util {
 				try {
 					DoCleanup ();
 				} catch (Exception ex) {
-					Logger.Log.Warn ("Caught exception cleaning up task '{0}'", Tag);
-					Logger.Log.Warn (ex);
+					Logger.Log.Warn (ex, "Caught exception cleaning up task '{0}'", Tag);
 				}
 			}
 
@@ -351,29 +357,28 @@ namespace Beagle.Util {
 				return this.GetHashCode () - other.GetHashCode ();
 			}
 
-			public override string ToString ()
+			public void AppendToStringBuilder (StringBuilder sb)
 			{
-				StringBuilder sb = new StringBuilder ();
-
-				sb.AppendFormat ("{0} {1} ({2})\n", Priority, SubPriority, Timestamp);
+				sb.Append (Priority).Append (' ').Append (SubPriority);
+				sb.Append (" (").Append (Timestamp).Append (")\n");
 					
-				sb.Append (Tag + "\n");
+				sb.Append (Tag).Append ('\n');
 
 				double t = (TriggerTime - DateTime.Now).TotalSeconds;
 				if (t > 0) {
 					if (t < 120)
 						sb.AppendFormat ("Hold for {0:0.00} seconds\n", t);
-					else
-						sb.AppendFormat ("Hold until {0}\n", TriggerTime);
+					else {
+						sb.Append ("Hold until ").Append (TriggerTime);
+						sb.Append ('\n');
+					}
 				}
 
 				if (Creator != null)
-					sb.AppendFormat ("Creator: {0}\n", Creator);
+					sb.Append ("Creator: ").Append (Creator).Append ('\n');
 
 				if (Description != null)
-					sb.Append (Description + "\n");
-
-				return sb.ToString ();
+					sb.Append (Description).Append ('\n');
 			}
 		}
 
@@ -460,8 +465,7 @@ namespace Beagle.Util {
 						try {
 							pre_hook ();
 						} catch (Exception ex) {
-							Logger.Log.Warn ("Caught exception in pre_hook of task group '{0}'", Name);
-							Logger.Log.Warn (ex);
+							Logger.Log.Warn (ex, "Caught exception in pre_hook of task group '{0}'", Name);
 						}
 					}
 					touched = true;
@@ -482,8 +486,7 @@ namespace Beagle.Util {
 						try {
 							post_hook ();
 						} catch (Exception ex) {
-							Logger.Log.Warn ("Caught exception in post_hook of task group '{0}'", Name);
-							Logger.Log.Warn (ex);
+							Logger.Log.Warn (ex, "Caught exception in post_hook of task group '{0}'", Name);
 						}
 					}
 					finished = true;
@@ -510,7 +513,7 @@ namespace Beagle.Util {
 
 		//////////////////////////////////////////////////////////////////////////////
 
-		static private double global_delay = -1.0;
+		private static double global_delay = -1.0;
 
 		static Scheduler ()
 		{
@@ -527,9 +530,9 @@ namespace Beagle.Util {
 
 		//////////////////////////////////////////////////////////////////////////////
 
-		static private Scheduler global = new Scheduler ();
+		private static Scheduler global = new Scheduler ();
 
-		static public Scheduler Global {
+		public static Scheduler Global {
 			get { return global; }
 		}
 
@@ -547,7 +550,10 @@ namespace Beagle.Util {
 		{
 			if (task == null)
 				return;
-			
+
+			if (task.Source == null)
+				throw new Exception ("Attempting to add Task with no source!");
+
 			Task old_task = null;
 
 			lock (big_lock) {
@@ -577,8 +583,6 @@ namespace Beagle.Util {
 						Logger.Log.Debug ("Desc: {0}", task.Description);
 				}
 
-
-
 				if (task.Priority == Priority.Shutdown)
 					shutdown_task_queue.Enqueue (task);
 				else
@@ -615,28 +619,37 @@ namespace Beagle.Util {
 
 		//////////////////////////////////////////////////////////////////////////////
 
-		Thread thread = null;
+		private Thread thread = null;
 		public bool running = false;
+		private static bool shutdown_requested = false;
 
 		public void Start ()
 		{
 			lock (this) {
-				if (thread != null)
+				if (shutdown_requested || thread != null)
 					return;
 				running = true;
-				thread = new Thread (new ThreadStart (Worker));
-				thread.Start ();
+				thread = ExceptionHandlingThread.Start (new ThreadStart (Worker));
+			}
+		}
+
+		public void Stop (bool to_shutdown)
+		{
+			lock (big_lock) {
+				shutdown_requested = to_shutdown;
+
+				if (running) {
+					running = false;
+					thread = null;
+					status_str = "Stopped";
+					Monitor.Pulse (big_lock);
+				}
 			}
 		}
 
 		public void Stop ()
 		{
-			lock (big_lock) {
-				if (running) {
-					running = false;
-					Monitor.Pulse (big_lock);
-				}
-			}
+			Stop (false);
 		}
 
 		//
@@ -694,13 +707,13 @@ namespace Beagle.Util {
 					// last immediate task was added, there is
 					// still a torrent of events coming in, and we
 					// may need to throttle.
-					if (last_add_delta.Seconds <= 1) {
+					if (last_add_delta.TotalSeconds <= 1) {
 						TimeSpan between_add_delta = last_immediate_times [4].Subtract (last_immediate_times [0]);
 
 						// At least 5 immediate tasks have been
 						// added in the last second.  We
 						// definitely need to throttle.
-						if (between_add_delta.Seconds <= 1) {
+						if (between_add_delta.TotalSeconds <= 1) {
 							need_throttle = true;
 							rate_factor = idle_scale * default_idle_rate_factor;
 						}
@@ -790,6 +803,7 @@ namespace Beagle.Util {
 			ArrayList to_be_executed = new ArrayList ();
 			Hashtable max_priority_by_source = new Hashtable ();
 			int executed_task_count = 0;
+			StringBuilder status_builder = new StringBuilder ();
 
 			while (running) {
 
@@ -801,6 +815,8 @@ namespace Beagle.Util {
 					// on our lock and then re-start our
 					// while loop
 					if (tasks_by_tag.Count == 0) {
+						if (EmptyQueueEvent != null)
+							EmptyQueueEvent ();
 						status_str = "Waiting on empty queue";
 						Monitor.Wait (big_lock);
 						executed_task_count = 0;
@@ -949,12 +965,13 @@ namespace Beagle.Util {
 
 				// Now actually execute the set of tasks we found.
 
-				StringBuilder status_builder;
-				status_builder = new StringBuilder ();
-				status_builder.AppendFormat ("Executing task{0}\n",
-							     to_be_executed.Count > 1 ? "s" : "");
+				status_builder.Length = 0;
+				status_builder.Append ("Executing task");
+				if (to_be_executed.Count > 1)
+					status_builder.Append ('s');
+				status_builder.Append ('\n');
 				foreach (Task task in to_be_executed) {
-					status_builder.Append (task.ToString ());
+					task.AppendToStringBuilder (status_builder);
 					status_builder.Append ('\n');
 				}
 				status_str = status_builder.ToString ();
@@ -964,8 +981,7 @@ namespace Beagle.Util {
 					try {
 						pre_hook ();
 					} catch (Exception ex) {
-						Logger.Log.Error ("Caught exception in pre_hook '{0}'", pre_hook);
-						Logger.Log.Error (ex);
+						Logger.Log.Error (ex, "Caught exception in pre_hook '{0}'", pre_hook);
 					}
 				}
 				foreach (Task task in to_be_executed) {
@@ -977,8 +993,7 @@ namespace Beagle.Util {
 					try {
 						post_hook ();
 					} catch (Exception ex) {
-						Logger.Log.Error ("Caught exception in post_hook '{0}'", post_hook);
-						Logger.Log.Error (ex);
+						Logger.Log.Error (ex, "Caught exception in post_hook '{0}'", post_hook);
 					}
 				}
 
@@ -1001,10 +1016,12 @@ namespace Beagle.Util {
 		
 		//////////////////////////////////////////////////////////////////////////////
 
-		public string GetHumanReadableStatus ()
+		private static StringBuilder cached_sb = new StringBuilder ();
+		
+		public SchedulerInformation GetCurrentStatus ()
 		{
-			StringBuilder sb = new StringBuilder ();
-
+		    SchedulerInformation current_status = new SchedulerInformation ();
+			
 			lock (big_lock) {
 				
 				ArrayList blocked_tasks = new ArrayList ();
@@ -1030,36 +1047,89 @@ namespace Beagle.Util {
 				pending_tasks.Sort ();
 				pending_tasks.Reverse ();
 
-				sb.Append ("Scheduler:\n");
-				sb.AppendFormat ("Count: {0}\n", total_executed_task_count);
-
-				if (status_str != null)
-					sb.AppendFormat ("Status: {0}\n", status_str);
-
-				int pos = 1;
-				sb.Append ("\nPending Tasks:\n");
 				foreach (Task task in pending_tasks) {
-					sb.AppendFormat ("{0} {1}\n", pos, task);
-					++pos;
-				}
-				if (pos == 1)
-					sb.Append ("Scheduler queue is empty.\n");
-
-
-				if (future_tasks.Count > 0) {
-					sb.Append ("\nFuture Tasks:\n");
-					foreach (Task task in future_tasks)
-						sb.AppendFormat ("{0}\n", task);
+					cached_sb.Length = 0;
+					task.AppendToStringBuilder (cached_sb);
+					current_status.PendingTasks.Add (cached_sb.ToString ());
 				}
 
-				if (blocked_tasks.Count > 0) {
-					sb.Append ("\nBlocked Tasks:\n");
-					foreach (Task task in blocked_tasks)
-						sb.AppendFormat ("{0}\n", task);
+				foreach (Task task in future_tasks) {
+					cached_sb.Length = 0;
+					task.AppendToStringBuilder (cached_sb);
+					current_status.FutureTasks.Add (cached_sb.ToString ());
 				}
+
+				foreach (Task task in blocked_tasks) {
+					cached_sb.Length = 0;
+					task.AppendToStringBuilder (cached_sb);
+					current_status.BlockedTasks.Add (cached_sb.ToString ());
+				}
+
+				current_status.TotalTaskCount = total_executed_task_count;
+				current_status.StatusString = status_str;
+
 			}
 
+			return current_status;
+		}
+
+	}
+
+	public class SchedulerInformation {
+		[XmlAttribute]
+		public int TotalTaskCount = -1;
+
+		[XmlAttribute]
+		public string StatusString;
+
+		[XmlArray]
+		[XmlArrayItem (ElementName="PendingTask", Type=typeof (string))]
+		public ArrayList PendingTasks = new ArrayList ();
+
+		[XmlArray]
+		[XmlArrayItem (ElementName="FutureTask", Type=typeof (string))]
+		public ArrayList FutureTasks = new ArrayList ();
+
+		[XmlArray]
+		[XmlArrayItem (ElementName="BlockedTask", Type=typeof (string))]
+		public ArrayList BlockedTasks = new ArrayList ();
+
+		private static StringBuilder sb = new StringBuilder ();
+
+		public string ToHumanReadableString ()
+		{
+			sb.Length = 0;
+
+			sb.Append ("Scheduler:\n");
+			sb.Append ("Count: ").Append (TotalTaskCount);
 			sb.Append ('\n');
+
+			if (StatusString != null)
+				sb.Append ("Status: ").Append (StatusString).Append ('\n');
+
+			int pos = 1;
+			sb.Append ("\nPending Tasks:\n");
+			if (PendingTasks != null && PendingTasks.Count > 0) {
+				foreach (string task in PendingTasks) {
+					sb.Append (pos).Append (' ').Append (task).Append ('\n');
+					++pos;
+				}
+			} else
+				sb.Append ("Scheduler queue is empty.\n");
+
+
+			if (FutureTasks != null && FutureTasks.Count > 0) {
+				sb.Append ("\nFuture Tasks:\n");
+				foreach (string task in FutureTasks)
+					sb.Append (task).Append ('\n');
+			}
+
+			if (BlockedTasks != null && BlockedTasks.Count > 0) {
+				sb.Append ("\nBlocked Tasks:\n");
+				foreach (string task in BlockedTasks)
+					sb.Append (task).Append ('\n');
+			}
+
 			return sb.ToString ();
 		}
 	}
@@ -1098,17 +1168,17 @@ namespace Beagle.Util {
 				Reschedule = true;
 		}
 
-		static void BeginTaskGroup ()
+		private static void BeginTaskGroup ()
 		{
 			Console.WriteLine ("--- Begin Task Group!");
 		}
 
-		static void EndTaskGroup ()
+		private static void EndTaskGroup ()
 		{
 			Console.WriteLine ("--- End Task Group!");
 		}
 
-		static void Main ()
+		public static void Main ()
 		{
 			Scheduler sched = Scheduler.Global;
 
