@@ -195,7 +195,6 @@ public abstract class Summary : IEnumerable {
 		public string uid, subject, from, to, cc, mlist;
 		public uint size, flags;
 		public DateTime sent, received;
-		public int x, y;
 
 		private void SkipContentInfo (FileStream f)
 		{
@@ -269,8 +268,12 @@ public abstract class Summary : IEnumerable {
 			return String.Format ("From: {0}\nTo: {1}\nSubject: {2}\nUID: {3}\n", from, to, subject, uid);
 		}
 
-		public DateTime Date {
-			get { return received.Ticks != 0 ? received : sent; }
+		public DateTime SentDate {
+			get { return sent; }
+		}
+		
+		public DateTime ReceivedDate {
+			get { return received; }
 		}
 		
 		private bool CheckFlag (CamelFlags test)
@@ -355,7 +358,7 @@ public abstract class Summary : IEnumerable {
 			return false;
 
 		    uint count = Decode.UInt (f);
-		    if (count == -1 || count > 500) {
+		    if (count > 500) {
 			return false;
 		    }
 		    
@@ -380,8 +383,9 @@ public abstract class Summary : IEnumerable {
 
 		    uint count;
 		    count = Decode.UInt (f);
-		    if (count == -1 || count > 500)
+		    if (count > 500)
 			return false;
+
 		    for (int i = 0; i < count; i++) {
 			// Name
 			Decode.SkipToken (f);
@@ -571,10 +575,14 @@ public abstract class Summary : IEnumerable {
 
 		public static DateTime Time (FileStream f)
 		{
-			byte [] b = new byte [4];
+			long seconds = 0;
 
-			f.Read (b, 0, 4);
-			long seconds = (b [0] << 24) | (b [1] << 16) | (b [2] << 8) | b [3];
+			// FIXME: Is it safe to assume that sizeof (time_t) == IntPtr.Size?  Probably not.
+			for (int i = IntPtr.Size - 1; i >= 0; i--) {
+				int v = f.ReadByte ();
+
+				seconds |= v << (i * 8);
+			}
 
 			if (seconds == 0)
 				return new DateTime (0);
