@@ -36,10 +36,6 @@ using GLib;
 using Beagle.Util;
 using Log = Beagle.Util.Log;
 
-#if ENABLE_WEBSERVICES
-using Beagle.WebService;
-#endif
-
 namespace Beagle.Daemon {
 	class BeagleDaemon {
 
@@ -82,14 +78,12 @@ namespace Beagle.Daemon {
 		private static void LogMemoryUsage ()
 		{
 			while (! Shutdown.ShutdownRequested) {
-				int vm_size = SystemInformation.VmSize;
 				int vm_rss = SystemInformation.VmRss;
 
-				Logger.Log.Debug ("Memory usage: VmSize={0:.0} MB, VmRSS={1:.0} MB,  GC.GetTotalMemory={2}",
-						  vm_size/1024.0, vm_rss/1024.0, GC.GetTotalMemory (false));
+				SystemInformation.LogMemoryUsage ();
 
-				if (vm_size > 300 * 1024) {
-					Logger.Log.Debug ("VmSize too large --- shutting down");
+				if (vm_rss > 300 * 1024) {
+					Logger.Log.Debug ("VmRss too large --- shutting down");
 					Shutdown.BeginShutdown ();
 				}
 
@@ -125,14 +119,6 @@ namespace Beagle.Daemon {
 				"  --disable-scheduler\tDisable the use of the scheduler.\n" +
 				"  --help\t\tPrint this usage message.\n";
 
-#if ENABLE_WEBSERVICES
-			usage += "\n" +
-				"  --web-global\t\tAllow global access to the Web & WebService interfaces.\n" +
-				"  --web-port\t\tPort to use for the internal web server.\n" +
-				"  --web-root\t\tRoot directory to use for the internal web server.\n" +
-				"  --web-disable\t\tDisable Web & WebServices functionality.\n";			
-#endif 
-
 			Console.WriteLine (usage);
 		}
 
@@ -148,9 +134,6 @@ namespace Beagle.Daemon {
 			if (! StartServer ()) {
 				if (arg_replace)
 				{
-#if ENABLE_WEBSERVICES
-					WebServiceBackEnd.Stop();
-#endif			
 					ReplaceExisting ();
 				}		
 				else {
@@ -162,10 +145,9 @@ namespace Beagle.Daemon {
 			}
 			
 			// Set up out-of-process indexing
-			if (Environment.GetEnvironmentVariable ("BEAGLE_ENABLE_IN_PROCESS_INDEXING") == null)
-				LuceneQueryable.IndexerHook = new LuceneQueryable.IndexerCreator (RemoteIndexer.NewRemoteIndexer);
+			LuceneQueryable.IndexerHook = new LuceneQueryable.IndexerCreator (RemoteIndexer.NewRemoteIndexer);
 
-			// Initialize syncronization to keep the indexes local if PathFinder.HomeDir
+			// Initialize synchronization to keep the indexes local if PathFinder.HomeDir
 			// is on a non-block device, or if BEAGLE_SYNCHRONIZE_LOCALLY is set
 			if ((! SystemInformation.IsPathOnBlockDevice (PathFinder.HomeDir) && Conf.Daemon.IndexSynchronization) ||
 			    Environment.GetEnvironmentVariable ("BEAGLE_SYNCHRONIZE_LOCALLY") != null)
@@ -200,16 +182,14 @@ namespace Beagle.Daemon {
 			// warning if not.  The actual advice calls will fail silently.
 			FileAdvise.TestAdvise ();
 
-#if ENABLE_WEBSERVICES		
-			//Beagle Web, WebService access initialization code:
-			WebServiceBackEnd.Start();
-#endif
 			Conf.WatchForUpdates ();
 
 			stopwatch.Stop ();
 
 			Logger.Log.Debug ("Daemon initialization finished after {0}", stopwatch);
 
+			SystemInformation.LogMemoryUsage (); 
+
 			if (arg_indexing_test_mode) {
 				Thread.Sleep (1000); // Ugly paranoia: wait a second for the backends to settle.
 				Logger.Log.Debug ("Running in indexing test mode");
@@ -236,11 +216,12 @@ namespace Beagle.Daemon {
 			}
 		}
 
-		[DllImport("libgobject-2.0.so")]
+		[DllImport("libgobject-2.0.so.0")]
 		static extern void g_type_init ();
 
 		public static void DoMain (string[] args)
 		{
+			SystemInformation.InternalCallInitializer.Init ();
 			SystemInformation.SetProcessName ("beagled");
 
 			// Process the command-line arguments
@@ -264,7 +245,8 @@ namespace Beagle.Daemon {
 
 				case "--heap-buddy":
 				case "--mdb":
-					// Silently ignore the --heap-buddy argument: it gets handled
+				case "--mono-debug":
+					// Silently ignore these arguments: they get handled
 					// in the wrapper script.
 					break;
 
@@ -372,28 +354,7 @@ namespace Beagle.Daemon {
 						Environment.Exit (0);
 					}
 					break;
-#if ENABLE_WEBSERVICES
-				case "--web-global":
-					WebServiceBackEnd.web_global = true;
-					WebServiceBackEnd.web_start = true;					
-					break;
 
-				case "--web-port":
-					WebServiceBackEnd.web_port = next_arg;
-					++i; 
-					WebServiceBackEnd.web_start = true;
-					break;
-
-				case "--web-root":
-					WebServiceBackEnd.web_rootDir = next_arg;
-					++i; 
-					WebServiceBackEnd.web_start = true;
-					break;
-					
-				case "--web-disable":
-					WebServiceBackEnd.web_start = false;
-					break;				
-#endif 
 				default:
 					Console.WriteLine ("Unknown argument '{0}'", arg);
 					Environment.Exit (1);
@@ -601,9 +562,6 @@ namespace Beagle.Daemon {
 
 		private static void OnShutdown ()
 		{
-#if ENABLE_WEBSERVICES
-			WebServiceBackEnd.Stop();
-#endif
 			// Stop our Inotify threads
 			Inotify.Stop ();
 
