@@ -13,14 +13,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 using System;
+
 namespace Lucene.Net.Store
 {
 	
-	/// <summary> A memory-resident {@link OutputStream} implementation.
+	/// <summary> A memory-resident {@link IndexOutput} implementation.
 	/// 
 	/// </summary>
-	/// <version>  $Id: RAMOutputStream.cs,v 1.3 2005/10/06 19:29:58 dsd Exp $
+	/// <version>  $Id: RAMOutputStream.cs,v 1.5 2006/10/02 17:11:11 joeshaw Exp $
 	/// </version>
 	
 	public class RAMOutputStream : BufferedIndexOutput
@@ -77,33 +79,35 @@ namespace Lucene.Net.Store
 		
 		public override void  FlushBuffer(byte[] src, int len)
 		{
-			int bufferNumber = pointer / BUFFER_SIZE;
-			int bufferOffset = pointer % BUFFER_SIZE;
-			int bytesInBuffer = BUFFER_SIZE - bufferOffset;
-			int bytesToCopy = bytesInBuffer >= len?len:bytesInBuffer;
+            byte[] buffer;
+            int bufferPos = 0;
+            while (bufferPos != len)
+            {
+                int bufferNumber = pointer / BUFFER_SIZE;
+                int bufferOffset = pointer % BUFFER_SIZE;
+                int bytesInBuffer = BUFFER_SIZE - bufferOffset;
+                int remainInSrcBuffer = len - bufferPos;
+                int bytesToCopy = bytesInBuffer >= remainInSrcBuffer ? remainInSrcBuffer : bytesInBuffer;
+				
+                if (bufferNumber == file.buffers.Count)
+                {
+                    buffer = new byte[BUFFER_SIZE];
+                    file.buffers.Add(buffer);
+                }
+                else
+                {
+                    buffer = (byte[]) file.buffers[bufferNumber];
+                }
+				
+                Array.Copy(src, bufferPos, buffer, bufferOffset, bytesToCopy);
+                bufferPos += bytesToCopy;
+                pointer += bytesToCopy;
+            }
 			
-			if (bufferNumber == file.buffers.Count)
-				file.buffers.Add(new byte[BUFFER_SIZE]);
+            if (pointer > file.length)
+                file.length = pointer;
 			
-			byte[] buffer = (byte[]) file.buffers[bufferNumber];
-			Array.Copy(src, 0, buffer, bufferOffset, bytesToCopy);
-			
-			if (bytesToCopy < len)
-			{
-				// not all in one buffer
-				int srcOffset = bytesToCopy;
-				bytesToCopy = len - bytesToCopy; // remaining bytes
-				bufferNumber++;
-				if (bufferNumber == file.buffers.Count)
-					file.buffers.Add(new byte[BUFFER_SIZE]);
-				buffer = (byte[]) file.buffers[bufferNumber];
-				Array.Copy(src, srcOffset, buffer, 0, bytesToCopy);
-			}
-			pointer += len;
-			if (pointer > file.length)
-				file.length = pointer;
-			
-			file.lastModified = System.DateTime.UtcNow.Ticks;
+            file.lastModified = System.DateTime.UtcNow.Ticks;
 		}
 		
 		public override void  Close()
