@@ -76,7 +76,8 @@ namespace Beagle.Daemon {
 		// 14: allow wildcard queries to also match keywords
 		// 15: analyze PropertyKeyword field, and store all properties as
 		//     lower case so that we're truly case insensitive.
-		private const int MAJOR_VERSION = 15;
+		// 16: add inverted timestamp to make querying substantially faster
+		private const int MAJOR_VERSION = 16;
 		private int minor_version = 0;
 
 		private string index_name;
@@ -378,10 +379,17 @@ namespace Beagle.Daemon {
 
 			private char [] buffer = new char [2];
 			private bool strip_extra_property_info = false;
+			private bool tokenize_email_hostname = false;
 
-			public BeagleAnalyzer (bool strip_extra_property_info)
+			public BeagleAnalyzer (bool is_indexing_analyzer)
 			{
-				this.strip_extra_property_info = strip_extra_property_info;
+				if (is_indexing_analyzer) {
+					this.strip_extra_property_info = true;
+					this.tokenize_email_hostname = true;
+				} else {
+					this.strip_extra_property_info = false;
+					this.tokenize_email_hostname = false;
+				}
 			}
 
 			public override TokenStream TokenStream (string fieldName, TextReader reader)
@@ -406,8 +414,17 @@ namespace Beagle.Daemon {
 					// If this is non-text property, just return one token
 					// containing the entire string.  We do this to avoid
 					// tokenizing keywords.
-					if (! is_text_prop)
-						return new LowerCaseFilter (new SingletonTokenStream (reader.ReadToEnd ()));
+					if (! is_text_prop) {
+						// We don't want to lower case the token if it's
+						// not in the private namespace.
+							
+						TokenStream singleton_stream = new SingletonTokenStream (reader.ReadToEnd ());
+						
+						if (fieldName.StartsWith ("prop:k:" + LuceneQueryingDriver.PrivateNamespace))
+							return singleton_stream;
+						else
+							return new LowerCaseFilter (singleton_stream);
+					}
 				} else if (fieldName == "PropertyKeyword")
 					return new LowerCaseFilter (new SingletonTokenStream (reader.ReadToEnd ()));
 
@@ -418,7 +435,7 @@ namespace Beagle.Daemon {
 				    || fieldName == "HotText"
 				    || fieldName == "PropertyText"
 				    || is_text_prop) {
-					outstream = new NoiseFilter (outstream);
+					outstream = new NoiseEmailHostFilter (outstream, tokenize_email_hostname);
 					outstream = new PorterStemFilter (outstream);
 				}
 
@@ -588,11 +605,11 @@ namespace Beagle.Daemon {
 
 			Field f;
 
-			f = Field.Keyword ("Uri", UriFu.UriToSerializableString (indexable.Uri));
+			f = Field.Keyword ("Uri", UriFu.UriToEscapedString (indexable.Uri));
 			primary_doc.Add (f);
 
 			if (indexable.ParentUri != null) {
-				f = Field.Keyword ("ParentUri", UriFu.UriToSerializableString (indexable.ParentUri));
+				f = Field.Keyword ("ParentUri", UriFu.UriToEscapedString (indexable.ParentUri));
 				primary_doc.Add (f);
 			}
 			
@@ -610,6 +627,12 @@ namespace Beagle.Daemon {
 				f = Field.UnStored (wildcard_field, str);
 				primary_doc.Add (f);
 
+				// Create an inverted timestamp so that we can
+				// sort by timestamp at search-time.
+				long timeval = Convert.ToInt64 (str);
+				f = Field.UnStored ("InvertedTimestamp", (Int64.MaxValue - timeval).ToString ());
+				primary_doc.Add (f);
+
 				str = StringFu.DateTimeToYearMonthString (indexable.Timestamp);
 				f = Field.Keyword ("YM:Timestamp", str);
 				primary_doc.Add (f);
@@ -677,7 +700,7 @@ namespace Beagle.Daemon {
 				if (prop.IsMutable) {
 					if (secondary_doc == null) {
 						secondary_doc = new Document ();
-						f = Field.Keyword ("Uri", UriFu.UriToSerializableString (indexable.Uri));
+						f = Field.Keyword ("Uri", UriFu.UriToEscapedString (indexable.Uri));
 						secondary_doc.Add (f);
 					}
 					target_doc = secondary_doc;
@@ -697,7 +720,7 @@ namespace Beagle.Daemon {
 			new_doc = new Document ();
 
 			Field uri_f;
-			uri_f = Field.Keyword ("Uri", UriFu.UriToSerializableString (prop_only_indexable.Uri));
+			uri_f = Field.Keyword ("Uri", UriFu.UriToEscapedString (prop_only_indexable.Uri));
 			new_doc.Add (uri_f);
 
 			Logger.Log.Debug ("Rewriting {0}", prop_only_indexable.DisplayUri);
@@ -736,7 +759,7 @@ namespace Beagle.Daemon {
 			uri = doc.Get ("Uri");
 			if (uri == null)
 				throw new Exception ("Got document from Lucene w/o a URI!");
-			return UriFu.UriStringToUri (uri);
+			return UriFu.EscapedStringToUri (uri);
 		}
 
 		static protected Hit DocumentToHit (Document doc)
@@ -749,7 +772,7 @@ namespace Beagle.Daemon {
 			string str;
 			str = doc.Get ("ParentUri");
 			if (str != null)
-				hit.ParentUri = UriFu.UriStringToUri (str);
+				hit.ParentUri = UriFu.EscapedStringToUri (str);
 			
 			hit.Timestamp = StringFu.StringToDateTime (doc.Get ("Timestamp"));
 
@@ -1371,7 +1394,7 @@ namespace Beagle.Daemon {
 
 		static protected LNS.Query UriQuery (string field_name, Uri uri)
 		{
-			return new LNS.TermQuery (new Term (field_name, UriFu.UriToSerializableString (uri)));
+			return new LNS.TermQuery (new Term (field_name, UriFu.UriToEscapedString (uri)));
 		}
 
 		static protected LNS.Query UriQuery (string field_name, ICollection uri_list)
