@@ -38,6 +38,7 @@ namespace Beagle.Daemon {
 	public class RemoteIndexer : IIndexer {
 
 		static string helper_path;
+		static int helper_pid = -1;
 
 		string remote_index_name;
 		int remote_index_minor_version = 0;
@@ -153,7 +154,7 @@ namespace Beagle.Daemon {
 						Logger.Log.Debug ("InnerException is IOException -- we probably need to launch a helper");
 						need_helper = true;
 					} else {
-						Logger.Log.Debug ("Exception was unexpected.  Details: {0}", ex);
+						Logger.Log.Debug (ex, "Exception was unexpected.");
 					}
 				}
 
@@ -220,9 +221,8 @@ namespace Beagle.Daemon {
 				
 				Logger.Log.Debug ("Launching helper process");
 
-				Process p = new Process ();
-				p.StartInfo.UseShellExecute = false;
-				p.StartInfo.FileName = helper_path;
+				SafeProcess p = new SafeProcess ();
+				p.Arguments = new string [] { helper_path };
 				p.Start ();
 
 				Logger.Log.Debug ("IndexHelper PID is {0}", p.Id);
@@ -247,7 +247,19 @@ namespace Beagle.Daemon {
 					throw new Exception (String.Format ("Couldn't launch helper process {0}", p.Id));
 
 				Logger.Log.Debug ("Found IndexHelper ({0}) in {1}", p.Id, watch);
+				helper_pid = p.Id;
 			}
 		}
+
+		static public void SignalRemoteIndexer ()
+		{
+			// No helper running right now
+			if (helper_pid == -1 || ! CheckHelper ()) {
+				helper_pid = -1;
+				return;
+			}
+
+			Mono.Unix.Native.Syscall.kill (helper_pid, Mono.Unix.Native.Signum.SIGUSR1);
+		}
 	}
 }
